@@ -1,25 +1,25 @@
-/* 
+/*
  * Mach Operating System
  * Copyright (c) 1991,1990 Carnegie Mellon University
  * All Rights Reserved.
- * 
+ *
  * Permission to use, copy, modify and distribute this software and its
  * documentation is hereby granted, provided that both the copyright
  * notice and this permission notice appear in all copies of the
  * software, derivative works or modified versions, and any portions
  * thereof, and that both notices appear in supporting documentation.
- * 
+ *
  * CARNEGIE MELLON ALLOWS FREE USE OF THIS SOFTWARE IN ITS "AS IS"
  * CONDITION.  CARNEGIE MELLON DISCLAIMS ANY LIABILITY OF ANY KIND FOR
  * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
- * 
+ *
  * Carnegie Mellon requests users of this software to return to
- * 
+ *
  *  Software Distribution Coordinator  or  Software.Distribution@CS.CMU.EDU
  *  School of Computer Science
  *  Carnegie Mellon University
  *  Pittsburgh PA 15213-3890
- * 
+ *
  * any improvements or extensions that they make and grant Carnegie Mellon
  * the rights to redistribute these changes.
  */
@@ -35,6 +35,10 @@
 static void
 WriteIncludes(FILE *file)
 {
+    fprintf(file, "#ifndef _GNU_SOURCE\n");
+    fprintf(file, "#define _GNU_SOURCE 1\n");
+    fprintf(file, "#endif\n\n");
+
     fprintf(file, "#define EXPORT_BOOLEAN\n");
     fprintf(file, "#include <mach/boolean.h>\n");
     fprintf(file, "#include <mach/kern_return.h>\n");
@@ -81,7 +85,7 @@ WriteProlog(FILE *file)
 {
     fprintf(file, "/* Module %s */\n", SubsystemName);
     fprintf(file, "\n");
-    
+
     WriteIncludes(file);
     WriteBogusDefines(file);
     WriteGlobalDecls(file);
@@ -348,7 +352,7 @@ WriteReplyInit(FILE *file, const routine_t *rt)
     {
 	printed_nl = TRUE;
 	fprintf(file, "\n");
-	fprintf(file, "\tmsgh_simple = %s;\n", 
+	fprintf(file, "\tmsgh_simple = %s;\n",
 			  strbool(rt->rtSimpleSendReply));
     }
 
